aboutsummaryrefslogtreecommitdiff
path: root/src/patch/patch_system.hh
diff options
context:
space:
mode:
authorjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2001-07-17 13:03:01 +0000
committerjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2001-07-17 13:03:01 +0000
commite9f98f912f0d686ec87ed5873899b0888ce0c6af (patch)
treec8c3a0505797140ff1cdd32ebfd3fe873913ebb0 /src/patch/patch_system.hh
parentc56f6221ff97e3e8a1594eaeb94da2ff525dd7bb (diff)
rename patch systems: now
full_grid hemisphere quadrant octant also fix some bugs in octant patch system setup routine git-svn-id: http://svn.einsteintoolkit.org/cactus/EinsteinAnalysis/AHFinderDirect/trunk@207 f88db872-0e4f-0410-b76b-b9085cfa78c5
Diffstat (limited to 'src/patch/patch_system.hh')
-rw-r--r--src/patch/patch_system.hh44
1 files changed, 24 insertions, 20 deletions
diff --git a/src/patch/patch_system.hh b/src/patch/patch_system.hh
index dfdb02b..0ed44a4 100644
--- a/src/patch/patch_system.hh
+++ b/src/patch/patch_system.hh
@@ -40,13 +40,14 @@ static const int max_N_patches = 6;
// Alas, we can't assign the same patch numbers to a given patch type
// in each type of patch system, and still keep each patch system having
// a contiguous range of patch numbers. (For example, the set of patches
// for a quarter patch system isn't a subset of the set of patches for
// a half patch system.)
//
//
// this (POD, and hence static-initializable) struct holds the constructor
// arguments which in practice vary from patch to patch
+//
struct patch_info
{
int patch_number;
@@ -69,9 +70,9 @@ struct patch_info
};
//
-// full-grid patch system
+// full-sphere patch system -- covers all 4pi steradians
//
-namespace full_patch_system_info
+namespace full_sphere_patch_system_info
{
static const int N_patches = 6;
@@ -95,10 +96,10 @@ static const struct patch_info minus_z = {5, 135.0, 225.0, 135.0, 225.0};
};
//
-// half-grid patch system
+// hemisphere (half) patch system -- covers +z half of sphere
// (mirror symmetry across z=0 plane)
//
-namespace half_patch_system_info
+namespace hemisphere_patch_system_info
{
static const int N_patches = 5;
@@ -119,10 +120,10 @@ static const struct patch_info minus_y = {4, -90.0, -45.0, -135.0, -45.0};
};
//
-// quarter-grid patch system
+// quarter-grid (quadrant) patch system -- covers +[xy] quadrant of sphere
// (90 degree periodic rotation symmetry about z axis)
//
-namespace quarter_patch_system_info
+namespace quadrant_patch_system_info
{
static const int N_patches = 4;
@@ -140,7 +141,7 @@ static const struct patch_info minus_z = {3, 135.0, 180.0, 135.0, 180.0};
};
//
// octant (eighth)-grid patch system
// (90 degree periodic rotation symmetry about z axis
// *and* mirror symmetry across z=0 plane)
//
@@ -178,9 +179,9 @@ public:
// what patch-system type are supported?
enum patch_system_type {
- full_patch_system,
- half_patch_system,
- quarter_patch_system,
+ full_sphere_patch_system,
+ hemisphere_patch_system,
+ quadrant_patch_system,
octant_patch_system
};
@@ -236,15 +237,18 @@ private:
//
// create/interlink patches, ghost zones, and frontiers
- void setup_full_patch_system(int N_ghost_zones, fp delta_drho_dsigma,
- int min_gfn_in, int max_gfn_in,
- int interpolator_order_in);
- void setup_half_patch_system(int N_ghost_zones, fp delta_drho_dsigma,
- int min_gfn_in, int max_gfn_in,
- int interpolator_order_in);
- void setup_quarter_patch_system(int N_ghost_zones, fp delta_drho_dsigma,
- int min_gfn_in, int max_gfn_in,
- int interpolator_order_in);
+ void setup_full_sphere_patch_system
+ (int N_ghost_zones, fp delta_drho_dsigma,
+ int min_gfn_in, int max_gfn_in,
+ int interpolator_order_in);
+ void setup_hemisphere_patch_system
+ (int N_ghost_zones, fp delta_drho_dsigma,
+ int min_gfn_in, int max_gfn_in,
+ int interpolator_order_in);
+ void setup_quadrant_patch_system
+ (int N_ghost_zones, fp delta_drho_dsigma,
+ int min_gfn_in, int max_gfn_in,
+ int interpolator_order_in);
void setup_octant_patch_system(int N_ghost_zones, fp delta_drho_dsigma,
int min_gfn_in, int max_gfn_in,
int interpolator_order_in);
@@ -40,13 +40,14 @@ static const int max_N_patches = 6;
// in each type of patch system, and still keep each patch system having
// a contiguous range of patch numbers. (For example, the set of patches
-// for a quarter patch system isn't a subset of the set of patches for
+// for a quadrant patch system isn't a subset of the set of patches for
// a half patch system.)
//
@@ -140,7 +141,7 @@ static const struct patch_info minus_z = {3, 135.0, 180.0, 135.0, 180.0};
};
//
-// octant (eighth)-grid patch system
+// eighth-grid (octant) patch system -- covers +[xyz] octant of sphere
// (90 degree periodic rotation symmetry about z axis
// *and* mirror symmetry across z=0 plane)